#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-engine
version:              0.4
visibility:           public
id:                   pandoc-lua-engine-0.4-1M8oty2sQUZI5sPjdeMeIQ
key:                  pandoc-lua-engine-0.4-1M8oty2sQUZI5sPjdeMeIQ
license:              GPL-2.0-or-later
copyright:            © 2006-2024 John MacFarlane, 2017-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  ade4a186de6aeda50b4ddf2edc6a1254
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Engine
    Text.Pandoc.Lua.Filter Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Module Text.Pandoc.Lua.Marshal.Chunks
    Text.Pandoc.Lua.Marshal.CommonState Text.Pandoc.Lua.Marshal.Context
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.ImageSize
    Text.Pandoc.Lua.Marshal.LogMessage
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.Image
    Text.Pandoc.Lua.Module.JSON Text.Pandoc.Lua.Module.Log
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Run
    Text.Pandoc.Lua.SourcePos Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.4-1M8oty2sQUZI5sPjdeMeIQ
depends:
    aeson-2.2.2.0-3wIqYzgVLxh1lGuh6CHfOQ base-4.18.2.1
    bytestring-0.11.5.3 citeproc-0.8.1.1-CjCMMHzaq2fLuPQuTnlmqh
    containers-0.6.7 crypton-1.0.4-LVSQvjJpmHeB02deJtb0Ng
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    doclayout-0.5.0.1-4qIjcmyQh911pxxCtzcokA
    doctemplates-0.11.0.1-EKJmqjyxllPB38wdGBZpbA exceptions-0.10.7
    hslua-2.3.0-3wtKwMTjtXJGlfwqrDtHtT
    hslua-module-doclayout-1.2.0-AHUGfiq1ACvBAOo9RmIehl
    hslua-module-path-1.1.1-ESafhdVH9jQKfolwqQ7BMl
    hslua-module-system-1.1.2-8kZaFsoWyGt7XvyvZiFPZ2
    hslua-module-text-1.1.0.1-9iZf7M9RCsJFIWzjzj5qcg
    hslua-module-version-1.1.1-A9DmfQxtvmm4CJjUqDM8q1
    hslua-module-zip-1.1.3-lFrofp7rVSKdt5ck4ge7z
    hslua-repl-0.1.2-FVFz9ilhnHX9Bb6HmKKxlR
    lpeg-1.1.0-Bzvb2c4RpRYB8j74nSYWPs mtl-2.3.1
    pandoc-3.6-3eK3JhhkrsoHJBwXTARl2i
    pandoc-lua-marshal-0.3.0-8El9hSoXwCT3qF2VYgqI2G
    pandoc-types-1.23.1-4ixGGX9TbW393jf05DapBw parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

